@@ -12,9 +12,7 @@
 #include <botan/ec_group.h>
 #include <botan/hex.h>
 #include <botan/numthry.h>
-#include <botan/reducer.h>
-
-namespace {
+#include <botan/internal/barrett.h>
 
 inline std::ostream& operator<<(std::ostream& o, const Botan::EC_AffinePoint& point) {
    o << Botan::hex_encode(point.serialize_uncompressed()) << "\n";
@@ -83,6 +81,4 @@ inline void check_ecc_math(const Botan::EC_Group& group, std::span<const uint8_t
    FUZZER_ASSERT_EQUAL(T2, R2);
 }
 
-}  // namespace
-
 #endif
