@@ -12,11 +12,25 @@
 
 #include <botan/internal/loadstor.h>
 #include <botan/internal/rotate.h>
+#include <span>
 
 namespace Botan {
 
 namespace {
 
+/*
+* Constant time DES [with assumptions on the cache]
+*
+* Each SBOX lookup (in function spbox below) examines just a single 64 byte range of this table,
+* converting it to the appropriate value using a multiplication and AND. Typically these tables
+* are otherwise 256 bytes, and thus the lookups leak information about the data being processed.
+* In constrast lookups within a single 64 byte cache line do not leak information [*] and we
+* can use alignas to ensure that the table entries are cache line aligned.
+*
+* [*] Assuming that the cache lines are at least 64 bytes long, and that the machine does not
+* suffer from cache bank conflicts. This is true for all Intel processors after Sandy Bridge,
+* and many other modern processors.
+*/
 alignas(256) const uint8_t SPBOX_CATS[64 * 8] = {
    0x54, 0x00, 0x10, 0x55, 0x51, 0x15, 0x01, 0x10, 0x04, 0x54, 0x55, 0x04, 0x45, 0x51, 0x40, 0x01,
    0x05, 0x44, 0x44, 0x14, 0x14, 0x50, 0x50, 0x45, 0x11, 0x41, 0x41, 0x11, 0x00, 0x05, 0x15, 0x40,
@@ -80,7 +94,7 @@ const uint32_t SPBOX_CAT_7_MASK = 0x10041040;
 /*
 * DES Key Schedule
 */
-void des_key_schedule(uint32_t round_key[32], const uint8_t key[8]) {
+void des_key_schedule(std::span<uint32_t, 32> round_key, const uint8_t key[8]) {
    static const uint8_t ROT[16] = {1, 1, 2, 2, 2, 2, 2, 2, 1, 2, 2, 2, 2, 2, 2, 1};
 
    uint32_t C = ((key[7] & 0x80) << 20) | ((key[6] & 0x80) << 19) | ((key[5] & 0x80) << 18) | ((key[4] & 0x80) << 17) |
@@ -132,7 +146,7 @@ inline uint32_t spbox(uint32_t T0, uint32_t T1) {
 /*
 * DES Encryption
 */
-inline void des_encrypt(uint32_t& Lr, uint32_t& Rr, const uint32_t round_key[32]) {
+inline void des_encrypt(uint32_t& Lr, uint32_t& Rr, std::span<const uint32_t, 32> round_key) {
    uint32_t L = Lr;
    uint32_t R = Rr;
    for(size_t i = 0; i != 16; i += 2) {
@@ -144,7 +158,8 @@ inline void des_encrypt(uint32_t& Lr, uint32_t& Rr, const uint32_t round_key[32]
    Rr = R;
 }
 
-inline void des_encrypt_x2(uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t& R1r, const uint32_t round_key[32]) {
+inline void des_encrypt_x2(
+   uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t& R1r, std::span<const uint32_t, 32> round_key) {
    uint32_t L0 = L0r;
    uint32_t R0 = R0r;
    uint32_t L1 = L1r;
@@ -167,7 +182,7 @@ inline void des_encrypt_x2(uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t
 /*
 * DES Decryption
 */
-inline void des_decrypt(uint32_t& Lr, uint32_t& Rr, const uint32_t round_key[32]) {
+inline void des_decrypt(uint32_t& Lr, uint32_t& Rr, std::span<const uint32_t, 32> round_key) {
    uint32_t L = Lr;
    uint32_t R = Rr;
    for(size_t i = 16; i != 0; i -= 2) {
@@ -178,7 +193,8 @@ inline void des_decrypt(uint32_t& Lr, uint32_t& Rr, const uint32_t round_key[32]
    Rr = R;
 }
 
-inline void des_decrypt_x2(uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t& R1r, const uint32_t round_key[32]) {
+inline void des_decrypt_x2(
+   uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t& R1r, std::span<const uint32_t, 32> round_key) {
    uint32_t L0 = L0r;
    uint32_t R0 = R0r;
    uint32_t L1 = L1r;
@@ -200,9 +216,8 @@ inline void des_decrypt_x2(uint32_t& L0r, uint32_t& R0r, uint32_t& L1r, uint32_t
 
 inline void des_IP(uint32_t& L, uint32_t& R) {
    // IP sequence by Wei Dai, taken from public domain Crypto++
-   uint32_t T;
    R = rotl<4>(R);
-   T = (L ^ R) & 0xF0F0F0F0;
+   uint32_t T = (L ^ R) & 0xF0F0F0F0;
    L ^= T;
    R = rotr<20>(R ^ T);
    T = (L ^ R) & 0xFFFF0000;
@@ -221,10 +236,9 @@ inline void des_IP(uint32_t& L, uint32_t& R) {
 
 inline void des_FP(uint32_t& L, uint32_t& R) {
    // FP sequence by Wei Dai, taken from public domain Crypto++
-   uint32_t T;
 
    R = rotr<1>(R);
-   T = (L ^ R) & 0xAAAAAAAA;
+   uint32_t T = (L ^ R) & 0xAAAAAAAA;
    R ^= T;
    L = rotr<9>(L ^ T);
    T = (L ^ R) & 0x00FF00FF;
@@ -258,7 +272,7 @@ void DES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
       des_IP(L0, R0);
       des_IP(L1, R1);
 
-      des_encrypt_x2(L0, R0, L1, R1, m_round_key.data());
+      des_encrypt_x2(L0, R0, L1, R1, std::span<const uint32_t, 32>{m_round_key});
 
       des_FP(L0, R0);
       des_FP(L1, R1);
@@ -274,7 +288,7 @@ void DES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
       uint32_t L0 = load_be<uint32_t>(in, 0);
       uint32_t R0 = load_be<uint32_t>(in, 1);
       des_IP(L0, R0);
-      des_encrypt(L0, R0, m_round_key.data());
+      des_encrypt(L0, R0, std::span<const uint32_t, 32>{m_round_key});
       des_FP(L0, R0);
       store_be(out, R0, L0);
 
@@ -290,6 +304,8 @@ void DES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
 void DES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
    assert_key_material_set();
 
+   const auto KS = std::span<const uint32_t, 32>{m_round_key};
+
    while(blocks >= 2) {
       uint32_t L0 = load_be<uint32_t>(in, 0);
       uint32_t R0 = load_be<uint32_t>(in, 1);
@@ -299,7 +315,7 @@ void DES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
       des_IP(L0, R0);
       des_IP(L1, R1);
 
-      des_decrypt_x2(L0, R0, L1, R1, m_round_key.data());
+      des_decrypt_x2(L0, R0, L1, R1, KS);
 
       des_FP(L0, R0);
       des_FP(L1, R1);
@@ -315,7 +331,7 @@ void DES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
       uint32_t L0 = load_be<uint32_t>(in, 0);
       uint32_t R0 = load_be<uint32_t>(in, 1);
       des_IP(L0, R0);
-      des_decrypt(L0, R0, m_round_key.data());
+      des_decrypt(L0, R0, KS);
       des_FP(L0, R0);
       store_be(out, R0, L0);
 
@@ -334,7 +350,8 @@ bool DES::has_keying_material() const {
 */
 void DES::key_schedule(std::span<const uint8_t> key) {
    m_round_key.resize(32);
-   des_key_schedule(m_round_key.data(), key.data());
+   const auto KS = std::span<uint32_t, 32>{m_round_key};
+   des_key_schedule(KS, key.data());
 }
 
 void DES::clear() {
@@ -347,6 +364,11 @@ void DES::clear() {
 void TripleDES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
    assert_key_material_set();
 
+   const auto KS = std::span<const uint32_t, 3 * 32>{m_round_key};
+   const auto K1 = KS.subspan<0, 32>();
+   const auto K2 = KS.subspan<32, 32>();
+   const auto K3 = KS.subspan<64, 32>();
+
    while(blocks >= 2) {
       uint32_t L0 = load_be<uint32_t>(in, 0);
       uint32_t R0 = load_be<uint32_t>(in, 1);
@@ -356,9 +378,9 @@ void TripleDES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) cons
       des_IP(L0, R0);
       des_IP(L1, R1);
 
-      des_encrypt_x2(L0, R0, L1, R1, &m_round_key[0]);
-      des_decrypt_x2(R0, L0, R1, L1, &m_round_key[32]);
-      des_encrypt_x2(L0, R0, L1, R1, &m_round_key[64]);
+      des_encrypt_x2(L0, R0, L1, R1, K1);
+      des_decrypt_x2(R0, L0, R1, L1, K2);
+      des_encrypt_x2(L0, R0, L1, R1, K3);
 
       des_FP(L0, R0);
       des_FP(L1, R1);
@@ -375,9 +397,9 @@ void TripleDES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) cons
       uint32_t R0 = load_be<uint32_t>(in, 1);
 
       des_IP(L0, R0);
-      des_encrypt(L0, R0, &m_round_key[0]);
-      des_decrypt(R0, L0, &m_round_key[32]);
-      des_encrypt(L0, R0, &m_round_key[64]);
+      des_encrypt(L0, R0, K1);
+      des_decrypt(R0, L0, K2);
+      des_encrypt(L0, R0, K3);
       des_FP(L0, R0);
 
       store_be(out, R0, L0);
@@ -394,6 +416,11 @@ void TripleDES::encrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) cons
 void TripleDES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) const {
    assert_key_material_set();
 
+   const auto KS = std::span<const uint32_t, 3 * 32>{m_round_key};
+   const auto K1 = KS.subspan<0, 32>();
+   const auto K2 = KS.subspan<32, 32>();
+   const auto K3 = KS.subspan<64, 32>();
+
    while(blocks >= 2) {
       uint32_t L0 = load_be<uint32_t>(in, 0);
       uint32_t R0 = load_be<uint32_t>(in, 1);
@@ -403,9 +430,9 @@ void TripleDES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) cons
       des_IP(L0, R0);
       des_IP(L1, R1);
 
-      des_decrypt_x2(L0, R0, L1, R1, &m_round_key[64]);
-      des_encrypt_x2(R0, L0, R1, L1, &m_round_key[32]);
-      des_decrypt_x2(L0, R0, L1, R1, &m_round_key[0]);
+      des_decrypt_x2(L0, R0, L1, R1, K3);
+      des_encrypt_x2(R0, L0, R1, L1, K2);
+      des_decrypt_x2(L0, R0, L1, R1, K1);
 
       des_FP(L0, R0);
       des_FP(L1, R1);
@@ -422,9 +449,9 @@ void TripleDES::decrypt_n(const uint8_t in[], uint8_t out[], size_t blocks) cons
       uint32_t R0 = load_be<uint32_t>(in, 1);
 
       des_IP(L0, R0);
-      des_decrypt(L0, R0, &m_round_key[64]);
-      des_encrypt(R0, L0, &m_round_key[32]);
-      des_decrypt(L0, R0, &m_round_key[0]);
+      des_decrypt(L0, R0, K3);
+      des_encrypt(R0, L0, K2);
+      des_decrypt(L0, R0, K1);
       des_FP(L0, R0);
 
       store_be(out, R0, L0);
@@ -444,13 +471,19 @@ bool TripleDES::has_keying_material() const {
 */
 void TripleDES::key_schedule(std::span<const uint8_t> key) {
    m_round_key.resize(3 * 32);
-   des_key_schedule(&m_round_key[0], key.first(8).data());
-   des_key_schedule(&m_round_key[32], key.subspan(8, 8).data());
+
+   auto KS = std::span<uint32_t, 3 * 32>{m_round_key};
+   auto K1 = KS.subspan<0, 32>();
+   auto K2 = KS.subspan<32, 32>();
+   auto K3 = KS.subspan<64, 32>();
+
+   des_key_schedule(K1, key.first(8).data());
+   des_key_schedule(K2, key.subspan(8, 8).data());
 
    if(key.size() == 24) {
-      des_key_schedule(&m_round_key[64], key.last(8).data());
+      des_key_schedule(K3, key.last(8).data());
    } else {
-      copy_mem(&m_round_key[64], &m_round_key[0], 32);
+      copy_mem(&m_round_key[64], K1.data(), 32);
    }
 }
 
