@@ -1,7 +1,7 @@
 /*
 * Base32 Encoding and Decoding
 * (C) 2018 Erwan Chaussy
-* (C) 2018,2020 Jack Lloyd
+* (C) 2018,2020,2025 Jack Lloyd
 *
 * Botan is released under the Simplified BSD License (see license.txt)
 */
@@ -12,6 +12,8 @@
 #include <botan/internal/codec_base.h>
 #include <botan/internal/ct_utils.h>
 #include <botan/internal/fmt.h>
+#include <botan/internal/int_utils.h>
+#include <botan/internal/loadstor.h>
 #include <botan/internal/rounding.h>
 
 namespace Botan {
@@ -22,23 +24,23 @@ class Base32 final {
    public:
       static std::string name() noexcept { return "base32"; }
 
-      static size_t encoding_bytes_in() noexcept { return m_encoding_bytes_in; }
+      static constexpr size_t encoding_bytes_in() noexcept { return m_encoding_bytes_in; }
 
-      static size_t encoding_bytes_out() noexcept { return m_encoding_bytes_out; }
+      static constexpr size_t encoding_bytes_out() noexcept { return m_encoding_bytes_out; }
 
-      static size_t decoding_bytes_in() noexcept { return m_encoding_bytes_out; }
+      static constexpr size_t decoding_bytes_in() noexcept { return m_encoding_bytes_out; }
 
-      static size_t decoding_bytes_out() noexcept { return m_encoding_bytes_in; }
+      static constexpr size_t decoding_bytes_out() noexcept { return m_encoding_bytes_in; }
 
-      static size_t bits_consumed() noexcept { return m_encoding_bits; }
+      static constexpr size_t bits_consumed() noexcept { return m_encoding_bits; }
 
-      static size_t remaining_bits_before_padding() noexcept { return m_remaining_bits_before_padding; }
+      static constexpr size_t remaining_bits_before_padding() noexcept { return m_remaining_bits_before_padding; }
 
-      static size_t encode_max_output(size_t input_length) {
+      static constexpr size_t encode_max_output(size_t input_length) {
          return (round_up(input_length, m_encoding_bytes_in) / m_encoding_bytes_in) * m_encoding_bytes_out;
       }
 
-      static size_t decode_max_output(size_t input_length) {
+      static constexpr size_t decode_max_output(size_t input_length) {
          return (round_up(input_length, m_encoding_bytes_out) * m_encoding_bytes_in) / m_encoding_bytes_out;
       }
 
@@ -56,27 +58,26 @@ class Base32 final {
          out_ptr[4] = (decode_buf[6] << 5) | decode_buf[7];
       }
 
-      static size_t bytes_to_remove(size_t final_truncate) { return final_truncate ? (final_truncate / 2) + 1 : 0; }
+      static size_t bytes_to_remove(size_t final_truncate) {
+         return (final_truncate > 0) ? (final_truncate / 2) + 1 : 0;
+      }
 
    private:
-      static const size_t m_encoding_bits = 5;
-      static const size_t m_remaining_bits_before_padding = 6;
+      static constexpr size_t m_encoding_bits = 5;
+      static constexpr size_t m_remaining_bits_before_padding = 6;
 
-      static const size_t m_encoding_bytes_in = 5;
-      static const size_t m_encoding_bytes_out = 8;
+      static constexpr size_t m_encoding_bytes_in = 5;
+      static constexpr size_t m_encoding_bytes_out = 8;
 };
 
 namespace {
 
-char lookup_base32_char(uint8_t x) {
-   BOTAN_DEBUG_ASSERT(x < 32);
+uint64_t lookup_base32_char(uint64_t x) {
+   uint64_t r = x;
+   r += swar_lt<uint64_t>(x, 0x1a1a1a1a1a1a1a1a) & 0x2929292929292929;
+   r += 0x1818181818181818;
 
-   const auto in_AZ = CT::Mask<uint8_t>::is_lt(x, 26);
-
-   const char c_AZ = 'A' + x;
-   const char c_27 = '2' + (x - 26);
-
-   return in_AZ.select(c_AZ, c_27);
+   return r;
 }
 
 }  // namespace
@@ -92,14 +93,16 @@ void Base32::encode(char out[8], const uint8_t in[5]) noexcept {
    const uint8_t b6 = ((in[3] & 0x03) << 3) | (in[4] >> 5);
    const uint8_t b7 = in[4] & 0x1F;
 
-   out[0] = lookup_base32_char(b0);
-   out[1] = lookup_base32_char(b1);
-   out[2] = lookup_base32_char(b2);
-   out[3] = lookup_base32_char(b3);
-   out[4] = lookup_base32_char(b4);
-   out[5] = lookup_base32_char(b5);
-   out[6] = lookup_base32_char(b6);
-   out[7] = lookup_base32_char(b7);
+   auto b = lookup_base32_char(make_uint64(b0, b1, b2, b3, b4, b5, b6, b7));
+
+   out[0] = static_cast<char>(get_byte<0>(b));
+   out[1] = static_cast<char>(get_byte<1>(b));
+   out[2] = static_cast<char>(get_byte<2>(b));
+   out[3] = static_cast<char>(get_byte<3>(b));
+   out[4] = static_cast<char>(get_byte<4>(b));
+   out[5] = static_cast<char>(get_byte<5>(b));
+   out[6] = static_cast<char>(get_byte<6>(b));
+   out[7] = static_cast<char>(get_byte<7>(b));
 }
 
 //static
@@ -167,4 +170,12 @@ secure_vector<uint8_t> base32_decode(std::string_view input, bool ignore_ws) {
    return base32_decode(input.data(), input.size(), ignore_ws);
 }
 
+size_t base32_encode_max_output(size_t input_length) {
+   return Base32::encode_max_output(input_length);
+}
+
+size_t base32_decode_max_output(size_t input_length) {
+   return Base32::decode_max_output(input_length);
+}
+
 }  // namespace Botan
