@@ -18,9 +18,9 @@ namespace Botan {
 */
 std::ostream& operator<<(std::ostream& stream, Pipe& pipe) {
    secure_vector<uint8_t> buffer(DefaultBufferSize);
-   while(stream.good() && pipe.remaining()) {
+   while(stream.good() && pipe.remaining() > 0) {
       const size_t got = pipe.read(buffer.data(), buffer.size());
-      stream.write(cast_uint8_ptr_to_char(buffer.data()), got);
+      stream.write(cast_uint8_ptr_to_char(buffer.data()), static_cast<std::streamsize>(got));
    }
    if(!stream.good()) {
       throw Stream_IO_Error("Pipe output operator (iostream) has failed");
@@ -34,7 +34,7 @@ std::ostream& operator<<(std::ostream& stream, Pipe& pipe) {
 std::istream& operator>>(std::istream& stream, Pipe& pipe) {
    secure_vector<uint8_t> buffer(DefaultBufferSize);
    while(stream.good()) {
-      stream.read(cast_uint8_ptr_to_char(buffer.data()), buffer.size());
+      stream.read(cast_uint8_ptr_to_char(buffer.data()), static_cast<std::streamsize>(buffer.size()));
       const size_t got = static_cast<size_t>(stream.gcount());
       pipe.write(buffer.data(), got);
    }
