@@ -18,10 +18,7 @@ namespace Botan {
 */
 class SecureQueueNode final {
    public:
-      SecureQueueNode() : m_buffer(DefaultBufferSize) {
-         m_next = nullptr;
-         m_start = m_end = 0;
-      }
+      SecureQueueNode() : m_next(nullptr), m_buffer(DefaultBufferSize), m_start(0), m_end(0) {}
 
       ~SecureQueueNode() {
          m_next = nullptr;
@@ -69,22 +66,20 @@ class SecureQueueNode final {
 /*
 * Create a SecureQueue
 */
-SecureQueue::SecureQueue() {
-   m_bytes_read = 0;
+SecureQueue::SecureQueue() : m_bytes_read(0) {
    set_next(nullptr, 0);
-   m_head = m_tail = new SecureQueueNode;
+   m_head = m_tail = new SecureQueueNode;  // NOLINT(*-owning-memory)
 }
 
 /*
 * Copy a SecureQueue
 */
-SecureQueue::SecureQueue(const SecureQueue& input) : Fanout_Filter(), DataSource() {
-   m_bytes_read = 0;
+SecureQueue::SecureQueue(const SecureQueue& input) : Fanout_Filter(), m_bytes_read(0) {
    set_next(nullptr, 0);
 
-   m_head = m_tail = new SecureQueueNode;
+   m_head = m_tail = new SecureQueueNode;  // NOLINT(*-owning-memory)
    SecureQueueNode* temp = input.m_head;
-   while(temp) {
+   while(temp != nullptr) {
       write(&temp->m_buffer[temp->m_start], temp->m_end - temp->m_start);
       temp = temp->m_next;
    }
@@ -95,9 +90,9 @@ SecureQueue::SecureQueue(const SecureQueue& input) : Fanout_Filter(), DataSource
 */
 void SecureQueue::destroy() {
    SecureQueueNode* temp = m_head;
-   while(temp) {
+   while(temp != nullptr) {
       SecureQueueNode* holder = temp->m_next;
-      delete temp;
+      delete temp;  // NOLINT(*-owning-memory)
       temp = holder;
    }
    m_head = m_tail = nullptr;
@@ -113,9 +108,9 @@ SecureQueue& SecureQueue::operator=(const SecureQueue& input) {
 
    destroy();
    m_bytes_read = input.get_bytes_read();
-   m_head = m_tail = new SecureQueueNode;
+   m_head = m_tail = new SecureQueueNode;  // NOLINT(*-owning-memory)
    SecureQueueNode* temp = input.m_head;
-   while(temp) {
+   while(temp != nullptr) {
       write(&temp->m_buffer[temp->m_start], temp->m_end - temp->m_start);
       temp = temp->m_next;
    }
@@ -126,15 +121,15 @@ SecureQueue& SecureQueue::operator=(const SecureQueue& input) {
 * Add some bytes to the queue
 */
 void SecureQueue::write(const uint8_t input[], size_t length) {
-   if(!m_head) {
-      m_head = m_tail = new SecureQueueNode;
+   if(m_head == nullptr) {
+      m_head = m_tail = new SecureQueueNode;  // NOLINT(*-owning-memory)
    }
-   while(length) {
+   while(length > 0) {
       const size_t n = m_tail->write(input, length);
       input += n;
       length -= n;
-      if(length) {
-         m_tail->m_next = new SecureQueueNode;
+      if(length > 0) {
+         m_tail->m_next = new SecureQueueNode;  // NOLINT(*-owning-memory)
          m_tail = m_tail->m_next;
       }
    }
@@ -145,14 +140,14 @@ void SecureQueue::write(const uint8_t input[], size_t length) {
 */
 size_t SecureQueue::read(uint8_t output[], size_t length) {
    size_t got = 0;
-   while(length && m_head) {
+   while(length > 0 && m_head != nullptr) {
       const size_t n = m_head->read(output, length);
       output += n;
       got += n;
       length -= n;
       if(m_head->size() == 0) {
          SecureQueueNode* holder = m_head->m_next;
-         delete m_head;
+         delete m_head;  // NOLINT(*-owning-memory)
          m_head = holder;
       }
    }
@@ -166,7 +161,7 @@ size_t SecureQueue::read(uint8_t output[], size_t length) {
 size_t SecureQueue::peek(uint8_t output[], size_t length, size_t offset) const {
    SecureQueueNode* current = m_head;
 
-   while(offset && current) {
+   while(offset > 0 && current != nullptr) {
       if(offset >= current->size()) {
          offset -= current->size();
          current = current->m_next;
@@ -176,7 +171,7 @@ size_t SecureQueue::peek(uint8_t output[], size_t length, size_t offset) const {
    }
 
    size_t got = 0;
-   while(length && current) {
+   while(length > 0 && current != nullptr) {
       const size_t n = current->peek(output, length, offset);
       offset = 0;
       output += n;
@@ -201,7 +196,7 @@ size_t SecureQueue::size() const {
    SecureQueueNode* current = m_head;
    size_t count = 0;
 
-   while(current) {
+   while(current != nullptr) {
       count += current->size();
       current = current->m_next;
    }
