@@ -16,13 +16,11 @@ namespace Botan {
 */
 std::ostream& operator<<(std::ostream& stream, const BigInt& n) {
    const auto stream_flags = stream.flags();
-   // NOLINTNEXTLINE(*-non-zero-enum-to-bool-conversion)
-   if(stream_flags & std::ios::oct) {
+   if((stream_flags & std::ios::oct) != 0) {
       throw Invalid_Argument("Octal output of BigInt not supported");
    }
 
-   // NOLINTNEXTLINE(*-non-zero-enum-to-bool-conversion)
-   const size_t base = (stream_flags & std::ios::hex) ? 16 : 10;
+   const size_t base = (stream_flags & std::ios::hex) != 0 ? 16 : 10;
 
    if(base == 10) {
       stream << n.to_dec_string();
