@@ -16,23 +16,33 @@
 namespace Botan {
 
 //static
-BigInt BigInt::add2(const BigInt& x, const word y[], size_t y_words, BigInt::Sign y_sign) {
+BigInt BigInt::add2(const BigInt& x, const word y[], size_t y_size, BigInt::Sign y_sign) {
    const size_t x_sw = x.sig_words();
 
-   BigInt z = BigInt::with_capacity(std::max(x_sw, y_words) + 1);
+   BigInt z = BigInt::with_capacity(std::max(x_sw, y_size) + 1);
 
    if(x.sign() == y_sign) {
-      bigint_add3(z.mutable_data(), x._data(), x_sw, y, y_words);
+      word carry = bigint_add3(z.mutable_data(), x._data(), x_sw, y, y_size);
+      z.mutable_data()[std::max(x_sw, y_size)] += carry;
       z.set_sign(x.sign());
    } else {
-      const int32_t relative_size = bigint_sub_abs(z.mutable_data(), x._data(), x_sw, y, y_words);
+      const int32_t relative_size = bigint_cmp(x.data(), x_sw, y, y_size);
 
-      //z.sign_fixup(relative_size, y_sign);
       if(relative_size < 0) {
+         // x < y so z = abs(y - x)
+         // NOLINTNEXTLINE(*-suspicious-call-argument) intentionally swapping x and y here
+         bigint_sub3(z.mutable_data(), y, y_size, x.data(), x_sw);
          z.set_sign(y_sign);
       } else if(relative_size == 0) {
-         z.set_sign(BigInt::Positive);
+         // Positive zero (nothing to do in this case)
       } else {
+         /*
+         * We know at this point that x >= y so if y_size is larger than
+         * x_sw, we are guaranteed they are just leading zeros which can
+         * be ignored
+         */
+         y_size = std::min(x_sw, y_size);
+         bigint_sub3(z.mutable_data(), x.data(), x_sw, y, y_size);
          z.set_sign(x.sign());
       }
    }
@@ -49,11 +59,11 @@ BigInt operator*(const BigInt& x, const BigInt& y) {
 
    BigInt z = BigInt::with_capacity(x.size() + y.size());
 
-   if(x_sw == 1 && y_sw) {
+   if(x_sw == 1 && y_sw > 0) {
       bigint_linmul3(z.mutable_data(), y._data(), y_sw, x.word_at(0));
-   } else if(y_sw == 1 && x_sw) {
+   } else if(y_sw == 1 && x_sw > 0) {
       bigint_linmul3(z.mutable_data(), x._data(), x_sw, y.word_at(0));
-   } else if(x_sw && y_sw) {
+   } else if(x_sw > 0 && y_sw > 0) {
       secure_vector<word> workspace(z.size());
 
       bigint_mul(z.mutable_data(),
@@ -81,7 +91,7 @@ BigInt operator*(const BigInt& x, word y) {
 
    BigInt z = BigInt::with_capacity(x_sw + 1);
 
-   if(x_sw && y) {
+   if(x_sw > 0 && y > 0) {
       bigint_linmul3(z.mutable_data(), x._data(), x_sw, y);
       z.set_sign(x.sign());
    }
@@ -97,7 +107,8 @@ BigInt operator/(const BigInt& x, const BigInt& y) {
       return x / y.word_at(0);
    }
 
-   BigInt q, r;
+   BigInt q;
+   BigInt r;
    vartime_divide(x, y, q, r);
    return q;
 }
@@ -111,7 +122,7 @@ BigInt operator/(const BigInt& x, word y) {
    }
 
    BigInt q;
-   word r;
+   word r = 0;
    ct_divide_word(x, y, q, r);
    return q;
 }
@@ -134,7 +145,8 @@ BigInt operator%(const BigInt& n, const BigInt& mod) {
       return BigInt::from_word(n % mod.word_at(0));
    }
 
-   BigInt q, r;
+   BigInt q;
+   BigInt r;
    vartime_divide(n, mod, q, r);
    return r;
 }
@@ -162,7 +174,7 @@ word operator%(const BigInt& n, word mod) {
       }
    }
 
-   if(remainder && n.sign() == BigInt::Negative) {
+   if(remainder != 0 && n.sign() == BigInt::Negative) {
       return mod - remainder;
    }
    return remainder;
