@@ -138,7 +138,7 @@ void ct_divide_word(const BigInt& x, word y, BigInt& q_out, word& r_out) {
       const auto r_carry = CT::Mask<word>::expand_top_bit(r);
 
       r <<= 1;
-      r += x_b;
+      r += static_cast<word>(x_b);
 
       const auto r_gte_y = CT::Mask<word>::is_gte(r, y) | r_carry;
       q.conditionally_set_bit(b, r_gte_y.as_bool());
@@ -159,7 +159,7 @@ void ct_divide_word(const BigInt& x, word y, BigInt& q_out, word& r_out) {
 
 BigInt ct_divide_word(const BigInt& x, word y) {
    BigInt q;
-   word r;
+   word r = 0;
    ct_divide_word(x, y, q, r);
    BOTAN_UNUSED(r);
    return q;
@@ -180,7 +180,7 @@ word ct_mod_word(const BigInt& x, word y) {
       const auto r_carry = CT::Mask<word>::expand_top_bit(r);
 
       r <<= 1;
-      r += x_b;
+      r += static_cast<word>(x_b);
 
       const auto r_gte_y = CT::Mask<word>::is_gte(r, y) | r_carry;
       r = r_gte_y.select(r - y, r);
@@ -296,7 +296,7 @@ void vartime_divide(const BigInt& x, const BigInt& y_arg, BigInt& q_out, BigInt&
       if(r.is_negative()) {
          qjt--;
          r += shifted_y;
-         BOTAN_DEBUG_ASSERT(r.is_positive());
+         BOTAN_ASSERT_NOMSG(r.is_positive());
       }
 
       q_words[j - t - 1] = qjt;
