@@ -131,7 +131,6 @@ class SM2_Signature_Operation final : public PK_Ops::Signature {
       std::vector<uint8_t> m_za;
       secure_vector<uint8_t> m_digest;
       std::unique_ptr<HashFunction> m_hash;
-      std::vector<BigInt> m_ws;
 };
 
 std::vector<uint8_t> SM2_Signature_Operation::sign(RandomNumberGenerator& rng) {
@@ -150,7 +149,7 @@ std::vector<uint8_t> SM2_Signature_Operation::sign(RandomNumberGenerator& rng) {
 
    const auto k = EC_Scalar::random(m_group, rng);
 
-   const auto r = EC_Scalar::gk_x_mod_order(k, rng, m_ws) + e;
+   const auto r = EC_Scalar::gk_x_mod_order(k, rng) + e;
    const auto s = (k - r * m_x) * m_da_inv;
 
    return EC_Scalar::serialize_pair(r, s);
@@ -253,7 +252,8 @@ std::unique_ptr<Private_Key> SM2_PublicKey::generate_another(RandomNumberGenerat
 std::unique_ptr<PK_Ops::Verification> SM2_PublicKey::create_verification_op(std::string_view params,
                                                                             std::string_view provider) const {
    if(provider == "base" || provider.empty()) {
-      std::string userid, hash;
+      std::string userid;
+      std::string hash;
       parse_sm2_param_string(params, userid, hash);
       return std::make_unique<SM2_Verification_Operation>(*this, userid, hash);
    }
@@ -265,7 +265,8 @@ std::unique_ptr<PK_Ops::Signature> SM2_PrivateKey::create_signature_op(RandomNum
                                                                        std::string_view params,
                                                                        std::string_view provider) const {
    if(provider == "base" || provider.empty()) {
-      std::string userid, hash;
+      std::string userid;
+      std::string hash;
       parse_sm2_param_string(params, userid, hash);
       return std::make_unique<SM2_Signature_Operation>(*this, userid, hash);
    }
