@@ -9,17 +9,17 @@
 
 #include <botan/internal/xmss_index_registry.h>
 
+#include <botan/assert.h>
 #include <botan/hash.h>
 #include <limits>
 
 namespace Botan {
 
-const std::string XMSS_Index_Registry::m_index_hash_function = "SHA-256";
-
 //static
 uint64_t XMSS_Index_Registry::make_key_id(const secure_vector<uint8_t>& private_seed,
                                           const secure_vector<uint8_t>& prf) {
-   std::unique_ptr<HashFunction> hash = HashFunction::create(m_index_hash_function);
+   const std::string_view index_hash_function = "SHA-256";
+   std::unique_ptr<HashFunction> hash = HashFunction::create(index_hash_function);
    BOTAN_ASSERT(hash != nullptr, "XMSS_Index_Registry requires SHA-256");
    hash->update(private_seed);
    hash->update(prf);
