@@ -18,16 +18,8 @@
 #include <botan/internal/tls_reader.h>
 
 #include <botan/dh.h>
-#include <botan/dl_group.h>
 #include <botan/ecdh.h>
 
-#if defined(BOTAN_HAS_X25519)
-   #include <botan/x25519.h>
-#endif
-#if defined(BOTAN_HAS_X448)
-   #include <botan/x448.h>
-#endif
-
 namespace Botan::TLS {
 
 /**
@@ -84,8 +76,8 @@ Server_Key_Exchange::Server_Key_Exchange(Handshake_IO& io,
       // `Policy::default_dh_group()` could return a `std::variant<Group_Params,
       // DL_Group>`, allowing it to define arbitrary groups.
       m_kex_key = state.callbacks().tls_generate_ephemeral_key(m_shared_group.value(), rng);
-      auto dh = dynamic_cast<DH_PrivateKey*>(m_kex_key.get());
-      if(!dh) {
+      auto* dh = dynamic_cast<DH_PrivateKey*>(m_kex_key.get());
+      if(dh == nullptr) {
          throw TLS_Exception(Alert::InternalError, "Application did not provide a Diffie-Hellman key");
       }
 
@@ -115,8 +107,8 @@ Server_Key_Exchange::Server_Key_Exchange(Handshake_IO& io,
          ecdh_public_val = m_kex_key->public_value();
       } else {
          m_kex_key = state.callbacks().tls_generate_ephemeral_key(m_shared_group.value(), rng);
-         auto ecdh = dynamic_cast<ECDH_PrivateKey*>(m_kex_key.get());
-         if(!ecdh) {
+         auto* ecdh = dynamic_cast<ECDH_PrivateKey*>(m_kex_key.get());
+         if(ecdh == nullptr) {
             throw TLS_Exception(Alert::InternalError, "Application did not provide a EC-Diffie-Hellman key");
          }
 
