@@ -14,6 +14,7 @@
 #include <botan/tls_ciphersuite.h>
 #include <botan/tls_exceptn.h>
 #include <botan/internal/ct_utils.h>
+#include <botan/internal/fmt.h>
 #include <botan/internal/loadstor.h>
 #include <botan/internal/tls_seq_numbers.h>
 #include <botan/internal/tls_session_key.h>
@@ -23,6 +24,10 @@
    #include <botan/internal/tls_cbc.h>
 #endif
 
+#if defined(BOTAN_HAS_TLS_NULL)
+   #include <botan/internal/tls_null.h>
+#endif
+
 namespace Botan::TLS {
 
 Connection_Cipher_State::Connection_Cipher_State(Protocol_Version version,
@@ -31,19 +36,21 @@ Connection_Cipher_State::Connection_Cipher_State(Protocol_Version version,
                                                  const Ciphersuite& suite,
                                                  const Session_Keys& keys,
                                                  bool uses_encrypt_then_mac) {
+   // NOLINTBEGIN(*-prefer-member-initializer)
    m_nonce_format = suite.nonce_format();
    m_nonce_bytes_from_record = suite.nonce_bytes_from_record(version);
    m_nonce_bytes_from_handshake = suite.nonce_bytes_from_handshake();
 
    const secure_vector<uint8_t>& aead_key = keys.aead_key(side);
    m_nonce = keys.nonce(side);
+   // NOLINTEND(*-prefer-member-initializer)
 
    BOTAN_ASSERT_NOMSG(m_nonce.size() == m_nonce_bytes_from_handshake);
 
    if(nonce_format() == Nonce_Format::CBC_MODE) {
 #if defined(BOTAN_HAS_TLS_CBC)
       // legacy CBC+HMAC mode
-      auto mac = MessageAuthenticationCode::create_or_throw("HMAC(" + suite.mac_algo() + ")");
+      auto mac = MessageAuthenticationCode::create_or_throw(fmt("HMAC({})", suite.mac_algo()));
       auto cipher = BlockCipher::create_or_throw(suite.cipher_algo());
 
       if(our_side) {
@@ -65,6 +72,18 @@ Connection_Cipher_State::Connection_Cipher_State(Protocol_Version version,
 #else
       BOTAN_UNUSED(uses_encrypt_then_mac);
       throw Internal_Error("Negotiated disabled TLS CBC+HMAC ciphersuite");
+#endif
+   } else if(nonce_format() == Nonce_Format::NULL_CIPHER) {
+#if defined(BOTAN_HAS_TLS_NULL)
+      auto mac = MessageAuthenticationCode::create_or_throw(fmt("HMAC({})", suite.mac_algo()));
+
+      if(our_side) {
+         m_aead = std::make_unique<TLS_NULL_HMAC_AEAD_Encryption>(std::move(mac), suite.mac_keylen());
+      } else {
+         m_aead = std::make_unique<TLS_NULL_HMAC_AEAD_Decryption>(std::move(mac), suite.mac_keylen());
+      }
+#else
+      throw Internal_Error("Negotiated disabled TLS NULL ciphersuite");
 #endif
    } else {
       m_aead =
@@ -76,6 +95,9 @@ Connection_Cipher_State::Connection_Cipher_State(Protocol_Version version,
 
 std::vector<uint8_t> Connection_Cipher_State::aead_nonce(uint64_t seq, RandomNumberGenerator& rng) {
    switch(m_nonce_format) {
+      case Nonce_Format::NULL_CIPHER: {
+         return std::vector<uint8_t>{};
+      }
       case Nonce_Format::CBC_MODE: {
          if(!m_nonce.empty()) {
             std::vector<uint8_t> nonce;
@@ -95,7 +117,7 @@ std::vector<uint8_t> Connection_Cipher_State::aead_nonce(uint64_t seq, RandomNum
       case Nonce_Format::AEAD_IMPLICIT_4: {
          BOTAN_ASSERT_NOMSG(m_nonce.size() == 4);
          std::vector<uint8_t> nonce(12);
-         copy_mem(&nonce[0], m_nonce.data(), 4);
+         copy_mem(&nonce[0], m_nonce.data(), 4);  // NOLINT(*container-data-pointer)
          store_be(seq, &nonce[nonce_bytes_from_handshake()]);
          return nonce;
       }
@@ -106,6 +128,9 @@ std::vector<uint8_t> Connection_Cipher_State::aead_nonce(uint64_t seq, RandomNum
 
 std::vector<uint8_t> Connection_Cipher_State::aead_nonce(const uint8_t record[], size_t record_len, uint64_t seq) {
    switch(m_nonce_format) {
+      case Nonce_Format::NULL_CIPHER: {
+         return std::vector<uint8_t>{};
+      }
       case Nonce_Format::CBC_MODE: {
          if(nonce_bytes_from_record() == 0 && !m_nonce.empty()) {
             std::vector<uint8_t> nonce;
@@ -130,7 +155,7 @@ std::vector<uint8_t> Connection_Cipher_State::aead_nonce(const uint8_t record[],
             throw Decoding_Error("Invalid AEAD packet too short to be valid");
          }
          std::vector<uint8_t> nonce(12);
-         copy_mem(&nonce[0], m_nonce.data(), 4);
+         copy_mem(&nonce[0], m_nonce.data(), 4);  // NOLINT(*container-data-pointer)
          copy_mem(&nonce[nonce_bytes_from_handshake()], record, nonce_bytes_from_record());
          return nonce;
       }
@@ -145,7 +170,7 @@ std::vector<uint8_t> Connection_Cipher_State::format_ad(uint64_t msg_sequence,
                                                         uint16_t msg_length) {
    std::vector<uint8_t> ad(13);
 
-   store_be(msg_sequence, &ad[0]);
+   store_be(msg_sequence, &ad[0]);  // NOLINT(*container-data-pointer)
    ad[8] = static_cast<uint8_t>(msg_type);
    ad[9] = version.major_version();
    ad[10] = version.minor_version();
@@ -370,7 +395,7 @@ Record_Header read_tls_record(secure_vector<uint8_t>& readbuf,
    uint16_t epoch = 0;
 
    uint64_t sequence = 0;
-   if(sequence_numbers) {
+   if(sequence_numbers != nullptr) {
       sequence = sequence_numbers->next_read_sequence();
       epoch = sequence_numbers->current_read_epoch();
    } else {
@@ -392,7 +417,7 @@ Record_Header read_tls_record(secure_vector<uint8_t>& readbuf,
 
    decrypt_record(recbuf, &readbuf[TLS_HEADER_SIZE], record_size, sequence, version, type, *cs);
 
-   if(sequence_numbers) {
+   if(sequence_numbers != nullptr) {
       sequence_numbers->read_accept(sequence);
    }
 
@@ -410,7 +435,7 @@ Record_Header read_dtls_record(secure_vector<uint8_t>& readbuf,
                                bool allow_epoch0_restart) {
    if(readbuf.size() < DTLS_HEADER_SIZE) {
       // header incomplete
-      if(fill_buffer_to(readbuf, input, input_len, consumed, DTLS_HEADER_SIZE)) {
+      if(fill_buffer_to(readbuf, input, input_len, consumed, DTLS_HEADER_SIZE) != 0) {
          readbuf.clear();
          return Record_Header(0);
       }
@@ -433,7 +458,7 @@ Record_Header read_dtls_record(secure_vector<uint8_t>& readbuf,
       return Record_Header(0);
    }
 
-   if(fill_buffer_to(readbuf, input, input_len, consumed, DTLS_HEADER_SIZE + record_size)) {
+   if(fill_buffer_to(readbuf, input, input_len, consumed, DTLS_HEADER_SIZE + record_size) != 0) {
       // Truncated packet?
       readbuf.clear();
       return Record_Header(0);
@@ -446,7 +471,7 @@ Record_Header read_dtls_record(secure_vector<uint8_t>& readbuf,
    const uint64_t sequence = load_be<uint64_t>(&readbuf[3], 0);
    const uint16_t epoch = (sequence >> 48);
 
-   const bool already_seen = sequence_numbers && sequence_numbers->already_seen(sequence);
+   const bool already_seen = sequence_numbers != nullptr && sequence_numbers->already_seen(sequence);
 
    if(already_seen && !(epoch == 0 && allow_epoch0_restart)) {
       readbuf.clear();
@@ -457,7 +482,7 @@ Record_Header read_dtls_record(secure_vector<uint8_t>& readbuf,
       // Unencrypted initial handshake
       recbuf.assign(readbuf.begin() + DTLS_HEADER_SIZE, readbuf.begin() + DTLS_HEADER_SIZE + record_size);
       readbuf.clear();
-      if(sequence_numbers) {
+      if(sequence_numbers != nullptr) {
          sequence_numbers->read_accept(sequence);
       }
       return Record_Header(sequence, version, type);
@@ -475,7 +500,7 @@ Record_Header read_dtls_record(secure_vector<uint8_t>& readbuf,
       return Record_Header(0);
    }
 
-   if(sequence_numbers) {
+   if(sequence_numbers != nullptr) {
       sequence_numbers->read_accept(sequence);
    }
 
