@@ -10,36 +10,22 @@
 
 #include <botan/tls_extensions.h>
 
-#include <botan/rng.h>
+#include <botan/ecdh.h>
 #include <botan/tls_callbacks.h>
 #include <botan/tls_exceptn.h>
 #include <botan/tls_policy.h>
-#include <botan/internal/ct_utils.h>
 #include <botan/internal/stl_util.h>
 #include <botan/internal/tls_reader.h>
-
 #include <algorithm>
 #include <utility>
 
-#if defined(BOTAN_HAS_X25519)
-   #include <botan/x25519.h>
-#endif
-
-#if defined(BOTAN_HAS_X448)
-   #include <botan/x448.h>
-#endif
-
-#include <botan/dh.h>
-#include <botan/dl_group.h>
-#include <botan/ecdh.h>
-
 namespace Botan::TLS {
 
 namespace {
 
 class Key_Share_Entry {
    public:
-      Key_Share_Entry(TLS_Data_Reader& reader) {
+      explicit Key_Share_Entry(TLS_Data_Reader& reader) {
          // TODO check that the group actually exists before casting...
          m_group = static_cast<Named_Group>(reader.get_uint16_t());
          m_key_exchange = reader.get_tls_length_value(2);
@@ -47,7 +33,7 @@ class Key_Share_Entry {
 
       // Create an empty Key_Share_Entry with the selected group
       // but don't pre-generate a keypair, yet.
-      Key_Share_Entry(const TLS::Group_Params group) : m_group(group) {}
+      explicit Key_Share_Entry(const TLS::Group_Params group) : m_group(group) {}
 
       Key_Share_Entry(const TLS::Group_Params group, Callbacks& cb, RandomNumberGenerator& rng) :
             m_group(group), m_private_key(cb.tls_kem_generate_key(group, rng)) {
@@ -58,8 +44,8 @@ class Key_Share_Entry {
          if(group.is_kem()) {
             m_key_exchange = m_private_key->public_key_bits();
          } else if(group.is_ecdh_named_curve()) {
-            auto pkey = dynamic_cast<ECDH_PublicKey*>(m_private_key.get());
-            if(!pkey) {
+            auto* pkey = dynamic_cast<ECDH_PublicKey*>(m_private_key.get());
+            if(pkey == nullptr) {
                throw TLS_Exception(Alert::InternalError, "Application did not provide a ECDH_PublicKey");
             }
 
@@ -73,8 +59,8 @@ class Key_Share_Entry {
             // ClientHello::prefers_compressed_ec_points() into account here.
             m_key_exchange = pkey->public_value(EC_Point_Format::Uncompressed);
          } else {
-            auto pkey = dynamic_cast<PK_Key_Agreement_Key*>(m_private_key.get());
-            if(!pkey) {
+            auto* pkey = dynamic_cast<PK_Key_Agreement_Key*>(m_private_key.get());
+            if(pkey == nullptr) {
                throw TLS_Exception(Alert::InternalError, "Application did not provide a key-agreement key");
             }
 
@@ -361,7 +347,7 @@ class Key_Share_HelloRetryRequest {
          m_selected_group = static_cast<Named_Group>(reader.get_uint16_t());
       }
 
-      Key_Share_HelloRetryRequest(Named_Group selected_group) : m_selected_group(selected_group) {}
+      explicit Key_Share_HelloRetryRequest(Named_Group selected_group) : m_selected_group(selected_group) {}
 
       ~Key_Share_HelloRetryRequest() = default;
 
@@ -394,10 +380,9 @@ class Key_Share::Key_Share_Impl {
    public:
       using Key_Share_Type = std::variant<Key_Share_ClientHello, Key_Share_ServerHello, Key_Share_HelloRetryRequest>;
 
-      Key_Share_Impl(Key_Share_Type ks) : key_share(std::move(ks)) {}
+      explicit Key_Share_Impl(Key_Share_Type ks) : key_share(std::move(ks)) {}
 
-      // NOLINTNEXTLINE(*-non-private-member-variables-in-classes)
-      Key_Share_Type key_share;
+      Key_Share_Type key_share;  // NOLINT(*-non-private-member-variable*)
 };
 
 Key_Share::Key_Share(TLS_Data_Reader& reader, uint16_t extension_size, Handshake_Type message_type) {
