@@ -23,6 +23,7 @@
 #include <botan/internal/loadstor.h>
 #include <botan/internal/stl_util.h>
 
+#include <memory>
 #include <optional>
 #include <span>
 #include <sstream>
@@ -65,7 +66,7 @@ using first_t = typename first_type<Ts...>::type;
 // TODO: C++26 will bring Parameter Pack indexing:
 //       auto first = s...[0];
 template <typename T0, typename... Ts>
-constexpr static first_t<T0, Ts...> first(T0&& t, Ts&&...) {
+constexpr static first_t<T0, Ts...> first(T0&& t, Ts&&... /*rest*/) {
    return std::forward<T0>(t);
 }
 
@@ -278,11 +279,12 @@ class bitvector_base final {
             ~bitref_base() = default;
 
          public:
+            // NOLINTNEXTLINE(*-explicit-conversions) FIXME
             constexpr operator bool() const noexcept { return is_set(); }
 
             constexpr bool is_set() const noexcept { return (m_block & m_mask) > 0; }
 
-            template <std::integral T>
+            template <std::unsigned_integral T>
             constexpr T as() const noexcept {
                return static_cast<T>(is_set());
             }
@@ -292,8 +294,8 @@ class bitvector_base final {
             }
 
          protected:
-            BlockT& m_block;  // NOLINT(*-non-private-member-variables-in-classes)
-            BlockT m_mask;    // NOLINT(*-non-private-member-variables-in-classes)
+            BlockT& m_block;  // NOLINT(*-non-private-member-variable*)
+            BlockT m_mask;    // NOLINT(*-non-private-member-variable*)
       };
 
    public:
@@ -372,7 +374,7 @@ class bitvector_base final {
    public:
       bitvector_base() : m_bits(0) {}
 
-      bitvector_base(size_type bits) : m_bits(bits), m_blocks(ceil_toblocks(bits)) {}
+      explicit bitvector_base(size_type bits) : m_bits(bits), m_blocks(ceil_toblocks(bits)) {}
 
       /**
        * Initialize the bitvector from a byte-array. Bits are taken byte-wise
@@ -387,7 +389,9 @@ class bitvector_base final {
        * @param bits  The number of bits to be loaded. This must not be more
        *              than the number of bytes in @p bytes.
        */
-      bitvector_base(std::span<const uint8_t> bytes, std::optional<size_type> bits = std::nullopt) {
+      bitvector_base(std::span<const uint8_t> bytes, /* NOLINT(*-explicit-conversions) FIXME */
+                     std::optional<size_type> bits = std::nullopt) :
+            m_bits() {
          from_bytes(bytes, bits);
       }
 
@@ -599,7 +603,9 @@ class bitvector_base final {
        */
       bitvector_base& set() {
          full_range_operation(
-            [](std::unsigned_integral auto block) -> decltype(block) { return static_cast<decltype(block)>(~0); },
+            [](std::unsigned_integral auto block) -> decltype(block) {
+               return static_cast<decltype(block)>(~static_cast<decltype(block)>(0));
+            },
             *this);
          zero_unused_bits();
          return *this;
@@ -922,7 +928,7 @@ class bitvector_base final {
       auto ref(size_type pos) { return bitref<block_type>(m_blocks, pos); }
 
    private:
-      enum class BitRangeAlignment { byte_aligned, no_alignment };
+      enum class BitRangeAlignment : uint8_t { byte_aligned, no_alignment };
 
       /**
        * Helper construction to implement bit range operations on the bitvector.
@@ -959,7 +965,7 @@ class bitvector_base final {
                BOTAN_ASSERT(m_source.size() >= m_start_bitoffset + m_bitlength, "enough bytes in underlying source");
             }
 
-            BitRangeOperator(BitvectorT& source) : BitRangeOperator(source, 0, source.size()) {}
+            explicit BitRangeOperator(BitvectorT& source) : BitRangeOperator(source, 0, source.size()) {}
 
             static constexpr bool is_byte_aligned() { return alignment == BitRangeAlignment::byte_aligned; }
 
@@ -1304,7 +1310,7 @@ namespace detail {
  * prefer it. Otherwise, the allocator of @p lhs will be used as a default.
  */
 template <bitvectorish T1, bitvectorish T2>
-constexpr auto copy_lhs_allocator_aware(const T1& lhs, const T2&) {
+constexpr auto copy_lhs_allocator_aware(const T1& lhs, const T2& /*rhs*/) {
    constexpr bool needs_secure_allocator =
       strong_type_wrapped_type<T1>::uses_secure_allocator || strong_type_wrapped_type<T2>::uses_secure_allocator;
 
