@@ -10,7 +10,11 @@
 
 #include <botan/exceptn.h>
 #include <botan/mem_ops.h>
-#include <botan/internal/cpuid.h>
+#include <botan/internal/target_info.h>
+
+#if defined(BOTAN_HAS_CPUID)
+   #include <botan/internal/cpuid.h>
+#endif
 
 #include <algorithm>
 #include <chrono>
@@ -18,10 +22,6 @@
 #include <iomanip>
 #include <sstream>
 
-#if defined(BOTAN_TARGET_OS_HAS_EXPLICIT_BZERO)
-   #include <string.h>
-#endif
-
 #if defined(BOTAN_TARGET_OS_HAS_POSIX1)
    #include <errno.h>
    #include <pthread.h>
@@ -44,11 +44,6 @@
    #include <sys/auxv.h>
 #endif
 
-#if defined(BOTAN_TARGET_OS_HAS_AUXINFO)
-   #include <dlfcn.h>
-   #include <elf.h>
-#endif
-
 #if defined(BOTAN_TARGET_OS_HAS_WIN32)
    #define NOMINMAX 1
    #define _WINSOCKAPI_  // stop windows.h including winsock.h
@@ -93,9 +88,7 @@ uint32_t OS::get_process_id() {
 
 namespace {
 
-#if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL) || defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO) || \
-   defined(BOTAN_TARGET_OS_HAS_AUXINFO)
-
+#if defined(BOTAN_TARGET_OS_HAS_GETAUXVAL) || defined(BOTAN_TARGET_OS_HAS_ELF_AUX_INFO)
    #define BOTAN_TARGET_HAS_AUXVAL_INTERFACE
 #endif
 
@@ -132,13 +125,6 @@ std::optional<unsigned long> get_auxval(std::optional<unsigned long> id) {
       if(::elf_aux_info(static_cast<int>(*id), &auxinfo, sizeof(auxinfo)) == 0) {
          return auxinfo;
       }
-#elif defined(BOTAN_TARGET_OS_HAS_AUXINFO)
-      for(const AuxInfo* auxinfo = static_cast<AuxInfo*>(::_dlauxinfo()); auxinfo != AT_NULL; ++auxinfo) {
-         if(*id == auxinfo->a_type) {
-            return auxinfo->a_v;
-         }
-      }
-      // no match; fall off the end and return nullopt
 #endif
    }
 
@@ -190,10 +176,18 @@ uint64_t OS::get_cpu_cycle_counter() {
 
 #elif defined(BOTAN_USE_GCC_INLINE_ASM)
 
-   #if defined(BOTAN_TARGET_CPU_IS_X86_FAMILY)
+   #if defined(BOTAN_TARGET_ARCH_IS_X86_64)
 
-   if(CPUID::has_rdtsc()) {
-      uint32_t rtc_low = 0, rtc_high = 0;
+   uint32_t rtc_low = 0;
+   uint32_t rtc_high = 0;
+   asm volatile("rdtsc" : "=d"(rtc_high), "=a"(rtc_low));
+   rtc = (static_cast<uint64_t>(rtc_high) << 32) | rtc_low;
+
+   #elif defined(BOTAN_TARGET_ARCH_IS_X86_FAMILY) && defined(BOTAN_HAS_CPUID)
+
+   if(CPUID::has(CPUID::Feature::RDTSC)) {
+      uint32_t rtc_low = 0;
+      uint32_t rtc_high = 0;
       asm volatile("rdtsc" : "=d"(rtc_high), "=a"(rtc_low));
       rtc = (static_cast<uint64_t>(rtc_high) << 32) | rtc_low;
    }
@@ -201,7 +195,9 @@ uint64_t OS::get_cpu_cycle_counter() {
    #elif defined(BOTAN_TARGET_ARCH_IS_PPC64)
 
    for(;;) {
-      uint32_t rtc_low = 0, rtc_high = 0, rtc_high2 = 0;
+      uint32_t rtc_low = 0;
+      uint32_t rtc_high = 0;
+      uint32_t rtc_high2 = 0;
       asm volatile("mftbu %0" : "=r"(rtc_high));
       asm volatile("mftb %0" : "=r"(rtc_low));
       asm volatile("mftbu %0" : "=r"(rtc_high2));
@@ -307,7 +303,8 @@ uint64_t OS::get_high_resolution_clock() {
    };
 
    for(clockid_t clock : clock_types) {
-      struct timespec ts;
+      struct timespec ts {};
+
       if(::clock_gettime(clock, &ts) == 0) {
          return (static_cast<uint64_t>(ts.tv_sec) * 1000000000) + static_cast<uint64_t>(ts.tv_nsec);
       }
@@ -325,7 +322,8 @@ uint64_t OS::get_high_resolution_clock() {
 
 uint64_t OS::get_system_timestamp_ns() {
 #if defined(BOTAN_TARGET_OS_HAS_CLOCK_GETTIME)
-   struct timespec ts;
+   struct timespec ts {};
+
    if(::clock_gettime(CLOCK_REALTIME, &ts) == 0) {
       return (static_cast<uint64_t>(ts.tv_sec) * 1000000000) + static_cast<uint64_t>(ts.tv_nsec);
    }
@@ -340,12 +338,16 @@ uint64_t OS::get_system_timestamp_ns() {
 }
 
 std::string OS::format_time(time_t time, const std::string& format) {
-   std::tm tm;
+   std::tm tm{};
 
 #if defined(BOTAN_TARGET_OS_HAS_WIN32)
-   localtime_s(&tm, &time);
+   if(::localtime_s(&tm, &time) != 0) {
+      throw Encoding_Error("Could not convert time_t to localtime");
+   }
 #elif defined(BOTAN_TARGET_OS_HAS_POSIX1)
-   localtime_r(&time, &tm);
+   if(::localtime_r(&time, &tm) == nullptr) {
+      throw Encoding_Error("Could not convert time_t to localtime");
+   }
 #else
    if(auto tmp = std::localtime(&time)) {
       tm = *tmp;
@@ -399,7 +401,7 @@ size_t OS::get_memory_locking_limit() {
       std::min<size_t>(read_env_variable_sz("BOTAN_MLOCK_POOL_SIZE", max_locked_kb), max_locked_kb);
 
    if(mlock_requested > 0) {
-      struct ::rlimit limits;
+      struct ::rlimit limits {};
 
       ::getrlimit(RLIMIT_MEMLOCK, &limits);
 
@@ -635,9 +637,7 @@ void OS::page_prohibit_access(void* page) {
 void OS::free_locked_pages(const std::vector<void*>& pages) {
    const size_t page_size = OS::system_page_size();
 
-   for(size_t i = 0; i != pages.size(); ++i) {
-      void* ptr = pages[i];
-
+   for(void* ptr : pages) {
       secure_scrub_memory(ptr, page_size);
 
       // ptr points to the data page, guard pages are before and after
@@ -657,6 +657,7 @@ void OS::free_locked_pages(const std::vector<void*>& pages) {
 void OS::page_named(void* page, size_t size) {
 #if defined(BOTAN_TARGET_OS_HAS_PRCTL) && defined(PR_SET_VMA) && defined(PR_SET_VMA_ANON_NAME)
    static constexpr char name[] = "Botan mlock pool";
+   // NOLINTNEXTLINE(*-vararg)
    int r = prctl(PR_SET_VMA, PR_SET_VMA_ANON_NAME, reinterpret_cast<uintptr_t>(page), size, name);
    BOTAN_UNUSED(r);
 #else
@@ -718,8 +719,9 @@ int OS::run_cpu_instruction_probe(const std::function<int()>& probe_fn) {
    volatile int probe_result = -3;
 
 #if defined(BOTAN_TARGET_OS_HAS_POSIX1) && !defined(BOTAN_TARGET_OS_IS_EMSCRIPTEN)
-   struct sigaction old_sigaction;
-   struct sigaction sigaction;
+   struct sigaction old_sigaction {};
+
+   struct sigaction sigaction {};
 
    sigaction.sa_handler = botan_sigill_handler;
    sigemptyset(&sigaction.sa_mask);
@@ -758,8 +760,7 @@ std::unique_ptr<OS::Echo_Suppression> OS::suppress_echo_on_terminal() {
 #if defined(BOTAN_TARGET_OS_HAS_POSIX1)
    class POSIX_Echo_Suppression : public Echo_Suppression {
       public:
-         POSIX_Echo_Suppression() {
-            m_stdin_fd = fileno(stdin);
+         POSIX_Echo_Suppression() : m_stdin_fd(fileno(stdin)), m_old_termios{} {
             if(::tcgetattr(m_stdin_fd, &m_old_termios) != 0) {
                throw System_Error("Getting terminal status failed", errno);
             }
