@@ -24,7 +24,7 @@ class ECKCDSA_Signature_KAT_Tests final : public PK_Signature_Generation_Test {
       ECKCDSA_Signature_KAT_Tests() :
             PK_Signature_Generation_Test("ECKCDSA", "pubkey/eckcdsa.vec", "Group,X,Hash,Msg,Nonce,Signature") {}
 
-      bool skip_this_test(const std::string&, const VarMap& vars) override {
+      bool skip_this_test(const std::string& /*header*/, const VarMap& vars) override {
          return !Botan::EC_Group::supports_named_group(vars.get_req_str("Group"));
       }
 
