@@ -37,7 +37,7 @@ static_assert(sizeof(TEST_DATA) == TEST_DATA_SIZE, "size of TEST_DATA must match
  */
 class MockChannel {
    public:
-      MockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) :
+      explicit MockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) :
             m_callbacks(std::move(core)),
             m_bytes_till_complete_record(TEST_DATA_SIZE),
             m_active(false),
@@ -82,18 +82,20 @@ class ThrowingMockChannel : public MockChannel {
    public:
       static boost::system::error_code expected_ec() { return Botan::TLS::Alert::UnexpectedMessage; }
 
-      ThrowingMockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) : MockChannel(std::move(core)) {}
+      explicit ThrowingMockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) : MockChannel(std::move(core)) {}
 
-      std::size_t received_data(std::span<const uint8_t>) { throw Botan::TLS::Unexpected_Message("test_error"); }
+      std::size_t received_data(std::span<const uint8_t> /*data*/) {
+         throw Botan::TLS::Unexpected_Message("test_error");
+      }
 
-      void send(std::span<const uint8_t>) { throw Botan::TLS::Unexpected_Message("test_error"); }
+      void send(std::span<const uint8_t> /*data*/) { throw Botan::TLS::Unexpected_Message("test_error"); }
 };
 
 class CancellingMockChannel : public MockChannel {
    public:
-      CancellingMockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) : MockChannel(std::move(core)) {}
+      explicit CancellingMockChannel(std::shared_ptr<Botan::TLS::Callbacks> core) : MockChannel(std::move(core)) {}
 
-      std::size_t received_data(std::span<const uint8_t>) {
+      std::size_t received_data(std::span<const uint8_t> /*data*/) {
          received_close_notify();
          return 0;
       }
@@ -113,8 +115,8 @@ using FailCount = boost::beast::test::fail_count;
 class AsioStream : public Botan::TLS::Stream<TestStream, MockChannel> {
    public:
       template <typename... Args>
-      AsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
-            Stream(context, std::forward<Args>(args)...) {
+      explicit AsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
+            Stream(std::move(context), std::forward<Args>(args)...) {
          m_native_handle = std::make_unique<MockChannel>(m_core);
       }
 };
@@ -122,8 +124,8 @@ class AsioStream : public Botan::TLS::Stream<TestStream, MockChannel> {
 class ThrowingAsioStream : public Botan::TLS::Stream<TestStream, ThrowingMockChannel> {
    public:
       template <typename... Args>
-      ThrowingAsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
-            Stream(context, std::forward<Args>(args)...) {
+      explicit ThrowingAsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
+            Stream(std::move(context), std::forward<Args>(args)...) {
          m_native_handle = std::make_unique<ThrowingMockChannel>(m_core);
       }
 };
@@ -131,8 +133,8 @@ class ThrowingAsioStream : public Botan::TLS::Stream<TestStream, ThrowingMockCha
 class CancellingAsioStream : public Botan::TLS::Stream<TestStream, CancellingMockChannel> {
    public:
       template <typename... Args>
-      CancellingAsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
-            Stream(context, std::forward<Args>(args)...) {
+      explicit CancellingAsioStream(std::shared_ptr<Botan::TLS::Context> context, Args&&... args) :
+            Stream(std::move(context), std::forward<Args>(args)...) {
          m_native_handle = std::make_unique<CancellingMockChannel>(m_core);
       }
 };
@@ -606,7 +608,7 @@ class Asio_Stream_Tests final : public Test {
          error_code ec;
 
          // this should be Botan::TLS::MAX_PLAINTEXT_SIZE + 1024 + 1
-         std::array<uint8_t, 17 * 1024 + 1> random_data;
+         std::array<uint8_t, 17 * 1024 + 1> random_data{};
          random_data.fill('4');  // chosen by fair dice roll
          random_data.back() = '5';
 
@@ -702,7 +704,7 @@ class Asio_Stream_Tests final : public Test {
          ssl.next_layer().connect(remote);
 
          // this should be Botan::TLS::MAX_PLAINTEXT_SIZE + 1024 + 1
-         std::array<uint8_t, 17 * 1024 + 1> random_data;
+         std::array<uint8_t, 17 * 1024 + 1> random_data{};
          random_data.fill('4');  // chosen by fair dice roll
          random_data.back() = '5';
 
